import React, { PureComponent } from 'react';
import { Card, Popover, Avatar, Icon } from 'antd';
import classnames from 'classnames';
import defaultAvatar from '../../assets/default_handsome.jpg';
import styles from './index.less';

const userEntranceList = [{
  name: '基本资料',
  icon: 'profile',
  path: '',
}, {
  name: '账户设置',
  icon: 'setting',
  path: '',
}, {
  name: '访问控制',
  icon: 'idcard',
  path: '',
}];

export default class AvatarIcon extends PureComponent {
  constructor(props) {
    super(props);
    this.state = {};
  }
  onLogoutClick = () => {
    const { onLogoutClick } = this.props;
    onLogoutClick({ key: 'logout' });
  }
  render() {
    const { avatar, account, popupAlign, className } = this.props;
    const avatarClass = classnames(className, styles.avatar);
    const trigger = (
      <span className={avatarClass}>
        <Avatar src={avatar || defaultAvatar} />
      </span>
    );
    const userBoxTitle = (
      <span>
        <Avatar src={avatar || defaultAvatar} />
        <p>{account}</p>
      </span>
    );
    const userBoxContent = (
      <div className={styles.userBoxContent}>
        <div className={styles.entranceCard}>
          {userEntranceList.map((entrance) => {
            return (
              <Card
                key={`user-box-entrance-${entrance.name}`}
                bordered={false}
                hoverable
              >
                <Icon type={entrance.icon} />
                <div>{entrance.name}</div>
              </Card>
            );
          })}
        </div>
        <a onClick={this.onLogoutClick} className={styles.logoutButton}>退出管理平台</a>
      </div>
    );
    return (
      <Popover
        placement="bottomRight"
        popupClassName={styles.popover}
        title={userBoxTitle}
        content={userBoxContent}
        trigger="hover"
        arrowPointAtCenter
        popupAlign={popupAlign}
      >
        {trigger}
      </Popover>
    );
  }
}
