import { message } from 'antd';
import { routerRedux } from 'dva/router';
import {
  queryProductList,
  queryProductItem,
  createProductItem,
  updateProductItem,
  deleteProductItem,
} from '../services/product';
import { Hotax } from '../utils/config';

export default {
  namespace: 'product',

  state: {
    list: [],
    pageNo: 1,
    pageSize: 15,
    totalSize: 0,
    currentItem: {},
  },

  effects: {
    *fetchCourseList({ payload }, { call, put }) {
      const response = yield call(queryProductList, { type: Hotax.PRODUCT_COURSE, ...payload });
      if (response.success) {
        yield put({
          type: 'querySuccess',
          payload: {
            list: response.data.list || [],
            pageSize: response.data.pageSize,
            totalSize: response.data.totalSize,
            pageNo: response.data.pageNo,
          },
        });
      }
    },
    *fetchSupportList({ payload }, { call, put }) {
      const response = yield call(queryProductList, { type: Hotax.PRODUCT_SUPPORT, ...payload });
      if (response.success) {
        yield put({
          type: 'querySuccess',
          payload: {
            list: response.data.list || [],
            pageSize: response.data.pageSize,
            totalSize: response.data.totalSize,
            pageNo: response.data.pageNo,
          },
        });
      }
    },
    *fetchTrainingList({ payload }, { call, put }) {
      const response = yield call(queryProductList, { type: Hotax.PRODUCT_TRAINING, ...payload });
      if (response.success) {
        yield put({
          type: 'querySuccess',
          payload: {
            list: response.data.list || [],
            pageSize: response.data.pageSize,
            totalSize: response.data.totalSize,
            pageNo: response.data.pageNo,
          },
        });
      }
    },
    *fetchPackageList({ payload }, { call, put }) {
      const response = yield call(queryProductList, { type: Hotax.PRODUCT_PACKAGE, ...payload });
      if (response.success) {
        yield put({
          type: 'querySuccess',
          payload: {
            list: response.data.list || [],
            pageSize: response.data.pageSize,
            totalSize: response.data.totalSize,
            pageNo: response.data.pageNo,
          },
        });
      }
    },
    *fetchProductItem({ payload }, { call, put }) {
      const response = yield call(queryProductItem, payload);
      if (response.success) {
        yield put({
          type: 'querySuccess',
          payload: {
            currentItem: response.data || {},
          },
        });
      }
    },
    *deleteCourseItem({ payload, states }, { call, put }) {
      const response = yield call(deleteProductItem, payload);
      if (response.success) {
        message.success('删除课程成功');
        yield put({
          type: 'fetchCourseList',
          payload: states.Queryers,
        });
      }
    },
    *deleteSupportItem({ payload, states }, { call, put }) {
      const response = yield call(deleteProductItem, payload);
      if (response.success) {
        message.success('删除配套成功');
        yield put({
          type: 'fetchSupportList',
          payload: states.Queryers,
        });
      }
    },
    *deleteTrainingItem({ payload, states }, { call, put }) {
      const response = yield call(deleteProductItem, payload);
      if (response.success) {
        message.success('删除师训成功');
        yield put({
          type: 'fetchTrainingList',
          payload: states.Queryers,
        });
      }
    },
    *deletePackageItem({ payload, states }, { call, put }) {
      const response = yield call(deleteProductItem, payload);
      if (response.success) {
        message.success('删除套餐包成功');
        yield put({
          type: 'fetchPackageList',
          payload: states.Queryers,
        });
      }
    },
    *createCourseItem({ payload, state }, { call, put }) {
      const response = yield call(createProductItem, { type: Hotax.PRODUCT_COURSE, ...payload });
      if (response.success) {
        message.success('创建课程成功');
        yield put(routerRedux.push({
          state,
          pathname: '/product/course/list',
        }));
      }
    },
    *createSupportItem({ payload, state }, { call, put }) {
      const response = yield call(createProductItem, { type: Hotax.PRODUCT_SUPPORT, ...payload });
      if (response.success) {
        message.success('创建配套成功');
        yield put(routerRedux.push({
          state,
          pathname: '/product/support/list',
        }));
      }
    },
    *createTrainingItem({ payload, state }, { call, put }) {
      const response = yield call(createProductItem, { type: Hotax.PRODUCT_TRAINING, ...payload });
      if (response.success) {
        message.success('创建师训成功');
        yield put(routerRedux.push({
          state,
          pathname: '/product/training/list',
        }));
      }
    },
    *createPackageItem({ payload, state }, { call, put }) {
      const response = yield call(createProductItem, { type: Hotax.PRODUCT_PACKAGE, ...payload });
      if (response.success) {
        message.success('创建套餐包成功');
        yield put(routerRedux.push({
          state,
          pathname: '/product/package/list',
        }));
      }
    },
    *updateCourseItem({ payload, states }, { call, put }) {
      const response = yield call(updateProductItem, { type: Hotax.PRODUCT_COURSE, ...payload });
      if (response.success) {
        message.success('修改课程成功');
        yield put(routerRedux.push({
          pathname: '/product/course/list',
          state: states,
        }));
      }
    },
    *updateSupportItem({ payload, states }, { call, put }) {
      const response = yield call(updateProductItem, { type: Hotax.PRODUCT_SUPPORT, ...payload });
      if (response.success) {
        message.success('修改配套成功');
        yield put(routerRedux.push({
          pathname: '/product/support/list',
          state: states,
        }));
      }
    },
    *updateTrainingItem({ payload, states }, { call, put }) {
      const response = yield call(updateProductItem, { type: Hotax.PRODUCT_TRAINING, ...payload });
      if (response.success) {
        message.success('修改师训成功');
        yield put(routerRedux.push({
          pathname: '/product/training/list',
          state: states,
        }));
      }
    },
    *updatePackageItem({ payload, states }, { call, put }) {
      const response = yield call(updateProductItem, { type: Hotax.PRODUCT_PACKAGE, ...payload });
      if (response.success) {
        message.success('修改套餐包成功');
        yield put(routerRedux.push({
          pathname: '/product/package/list',
          state: states,
        }));
      }
    },
  },

  reducers: {
    querySuccess(state, action) {
      return {
        ...state,
        ...action.payload,
      };
    },
    cleanItemState(state) {
      return {
        ...state,
        currentItem: {},
      };
    },
    fixCurrentItem(state, action) {
      const { currentItem } = state;
      return {
        ...state,
        currentItem: {
          ...currentItem,
          ...action.payload,
        },
      };
    },
  },
};
