import { message } from 'antd';
import { routerRedux } from 'dva/router';
import {
  queryTagGroupList,
  queryTagGroupItem,
  createTagGroupItem,
  updateTagGroupItem,
  deleteTagGroupItem,
} from '../services/tagGroup';

export default {
  namespace: 'tagGroup',

  state: {
    list: [],
    pageNo: 1,
    pageSize: 15,
    totalSize: 0,
    currentItem: {},
  },

  effects: {
    *fetchTagGroupList({ payload }, { call, put }) {
      const response = yield call(queryTagGroupList, payload);
      if (response.success) {
        yield put({
          type: 'querySuccess',
          payload: {
            list: response.data.list || [],
            pageSize: response.data.pageSize,
            totalSize: response.data.totalSize,
            pageNo: response.data.pageNo,
          },
        });
      }
    },
    *fetchTagGroupItem({ payload }, { call, put }) {
      const response = yield call(queryTagGroupItem, payload);
      if (response.success) {
        yield put({
          type: 'querySuccess',
          payload: {
            currentItem: response.data || {},
          },
        });
      }
    },
    *createTagGroupItem({ payload, state }, { call, put }) {
      const response = yield call(createTagGroupItem, payload);
      if (response.success) {
        message.success('创建标签组成功');
        yield put(routerRedux.push({
          state,
          pathname: '/frontend/tagGroup',
        }));
      }
    },
    *deleteTagGroupItem({ payload, states }, { call, put }) {
      const response = yield call(deleteTagGroupItem, payload);
      if (response.success) {
        message.success('删除标签组成功');
        yield put({
          type: 'fetchTagGroupList',
          payload: states.Queryers,
        });
      }
    },
    *updateTagGroupItem({ payload, states }, { call, put }) {
      const response = yield call(updateTagGroupItem, payload);
      if (response.success) {
        message.success('修改标签组成功');
        yield put(routerRedux.push({
          pathname: '/frontend/tagGroup',
          state: states,
        }));
      }
    },
  },

  reducers: {
    querySuccess(state, action) {
      return {
        ...state,
        ...action.payload,
      };
    },
    fixCurrentItem(state, action) {
      return {
        ...state,
        currentItem: {
          ...state.currentItem,
          ...action.payload,
        },
      };
    },
    cleanItemState(state) {
      return {
        ...state,
        currentItem: {},
      };
    },
  },
};
