import React, { PureComponent } from 'react';
import { connect } from 'dva';
import { routerRedux } from 'dva/router';
import { Card, Form, Input, Button } from 'antd';
import PageHeaderLayout from '../../layouts/PageHeaderLayout';
import FooterToolbar from '../../components/FooterToolbar';
import { toDecimal2 } from '../../utils/utils';
import styles from './MerchantDeposit.less';

const fieldLabels = {
  code: '商户编号',
  name: '商户名称',
  balance: '账户余额',
  quantity: '充值金额',
  note: '备注',
};
const formItemLayout = {
  labelCol: {
    xs: { span: 24 },
    sm: { span: 6 },
  },
  wrapperCol: {
    xs: { span: 24 },
    sm: { span: 14 },
    md: { span: 12 },
  },
};

@Form.create()
@connect(({ loading, merchant }) => ({
  merchant,
  submitting: loading.models.merchant,
}))
export default class MerchantDepositPage extends PureComponent {
  handlePageBack = () => {
    this.props.dispatch(routerRedux.push({
      pathname: '/merchant/list',
      state: this.props.location.state,
    }));
  }
  handlePageSubmit = (e) => {
    e.preventDefault();
    this.props.form.validateFieldsAndScroll((err, values) => {
      if (!err) {
        const { note, quantity } = values;
        const { id } = this.props.location.state.currentItem;
        this.props.dispatch({
          type: 'merchant/depositMerchantItem',
          payload: {
            note,
            quantity,
            merchantId: id,
          },
          states: this.props.location.state,
        });
      }
    });
  }
  render() {
    const { location, form, submitting } = this.props;
    const { currentItem } = location.state;
    const { getFieldDecorator } = form;
    return (
      <PageHeaderLayout>
        <Card style={{ marginBottom: 70 }}>
          <Form>
            <Form.Item label={fieldLabels.name} {...formItemLayout}>
              <span>{`${currentItem.name}【${currentItem.code}】`}</span>
            </Form.Item>
            <Form.Item label={fieldLabels.balance} {...formItemLayout}>
              <span className={styles.balance}>{toDecimal2(currentItem.balance)}元</span>
            </Form.Item>
            <Form.Item label={fieldLabels.quantity} {...formItemLayout}>
              {getFieldDecorator('quantity', {
                rules: [
                  {
                    required: true, type: 'string', message: '充值金额不能为空!',
                  }, {
                    pattern: /(^[1-9]([0-9]+)?(\.[0-9]{1,2})?$)|(^(0){1}$)|(^[0-9]\.[0-9]([0-9])?$)/, message: '充值金额格式错误!',
                  },
                ],
              })(
                <Input placeholder="请输入充值金额" addonAfter="元" />
              )}
            </Form.Item>
            <Form.Item label={fieldLabels.note} {...formItemLayout}>
              {getFieldDecorator('note', {
              })(
                <Input placeholder="请输入" />
              )}
            </Form.Item>
          </Form>
        </Card>
        <FooterToolbar style={{ width: '100%' }}>
          <Button onClick={this.handlePageBack} style={{ marginRight: 10 }}>
            取消
          </Button>
          <Button type="primary" onClick={this.handlePageSubmit} loading={submitting}>
            提交
          </Button>
        </FooterToolbar>
      </PageHeaderLayout>
    );
  }
}
