import React, { Component } from 'react';
import pathToRegexp from 'path-to-regexp';
import { connect } from 'dva';
import { routerRedux } from 'dva/router';
import { Form, Modal, Card, Icon, Button, Input, Radio, Switch } from 'antd';
import AXDragSortTable from '../../../components/AXDragSortTable';
import Selector from '../../../components/AXTableSelector/Selector';
import FooterToolbar from '../../../components/FooterToolbar';
import {
  genAbsolutePicUrl,
  statusToBool,
  boolToStatus,
  getResourceTypeName,
} from '../../../utils/utils';
import { Hotax } from '../../../utils/config';
import styles from './CoursewareCreate.less';

const fieldLabels = {
  code: '课件编号',
  title: '课件名称',
  category: '环节名称',
  digest: '课件简述',
  resourceList: '资源列表',
  status: '课件状态',
};
const formItemLayout = {
  labelCol: {
    xs: { span: 24 },
    sm: { span: 2 },
  },
  wrapperCol: {
    xs: { span: 24 },
    sm: { span: 14 },
    md: { span: 12 },
  },
};

@connect(({ loading, courseware, resource }) => ({
  resource,
  courseware,
  loading: loading.models.resource,
  submitting: loading.models.courseware,
}))
@Form.create()
export default class CoursewareCreatePage extends Component {
  state = {
    modalSelectorDestroy: true,
    resourceType: 'Picture',
  };
  componentWillMount() {
    // 进入页面前清空下model中state内容，防止上次内容造成干扰
    const match = pathToRegexp('/product/courseware/create').exec(this.props.location.pathname);
    if (match) {
      this.props.dispatch({
        type: 'courseware/cleanItemState',
        payload: {},
      });
    }
  }
  componentDidMount() {
    // 组件挂载完成，检查是否是编辑操作，决定是否加载该课件数据
    const matchId = this.isEdit();
    if (matchId) {
      this.props.dispatch({
        type: 'courseware/fetchCoursewareItem',
        payload: { id: matchId },
      });
    }
  }
  isEdit = () => {
    const { location } = this.props;
    const match = pathToRegexp('/product/courseware/edit/:id').exec(location.pathname);
    if (match) {
      return match[1];
    }
    return false;
  };
  selectorDataFetcher = (params) => {
    const { resourceType } = this.state;
    if (resourceType === 'Picture') {
      this.props.dispatch({
        type: 'resource/fetchImageList',
        payload: params,
      });
    }
    if (resourceType === 'Video') {
      this.props.dispatch({
        type: 'resource/fetchVideoList',
        payload: params,
      });
    }
    if (resourceType === 'AudioBook') {
      this.props.dispatch({
        type: 'resource/fetchAudioBookList',
        payload: params,
      });
    }
  };
  handleSelectorModalShow = () => {
    this.setState({
      modalSelectorDestroy: false,
    });
    this.selectorDataFetcher();
  };
  handleSelectorCancel = () => {
    this.setState({
      modalSelectorDestroy: true,
    });
  };
  handleSelectorFinish = (rows) => {
    this.setState({
      modalSelectorDestroy: true,
    });
    this.props.dispatch({
      type: 'courseware/fixResourceList',
      payload: rows,
    });
  };
  handleSelectorChange = (params) => {
    this.selectorDataFetcher(params);
  };
  handleRadioChange = (e) => {
    this.setState({
      resourceType: e.target.value,
    }, () => this.selectorDataFetcher());
    this.props.dispatch({
      type: 'courseware/fixResourceList',
      payload: [],
    });
  };
  handleDragSortTableChange = (rows) => {
    this.props.dispatch({
      type: 'courseware/fixResourceList',
      payload: rows,
    });
  };
  /**
   * 点击跳转到资源编辑页面
   * @param record
   */
  handleResourceEdit = (record) => {
    const { type, id } = record;
    if (Hotax.RESOURCE_AUDIOBOOK === type) {
      const genAudioBook = (obj = {}) => {
        const { code, name, img, audio, status } = obj;
        return {
          code,
          name,
          status,
          id: obj.id,
          img: img || {},
          audio: audio || {},
        };
      };
      this.props.dispatch(routerRedux.push({
        pathname: `/resource/audiobook-edit/${id}`,
        state: { audioBookItem: genAudioBook(record) },
      }));
    } else if (Hotax.RESOURCE_VIDEO === type) {
      this.props.dispatch(routerRedux.push({
        pathname: `/resource/video-edit/${id}`,
        state: { ...record },
      }));
    } else if (Hotax.RESOURCE_IMAGE === type) {
      this.props.dispatch(routerRedux.push({
        pathname: `/resource/picture-edit/${id}`,
        state: { ...record },
      }));
    }
  };
  handlePageBack = () => {
    this.props.dispatch(routerRedux.push({
      pathname: '/product/courseware/list',
      state: this.props.location.state,
    }));
  };
  handlePageSubmit = (e) => {
    e.preventDefault();
    this.props.form.validateFieldsAndScroll((err, values) => {
      if (!err) {
        const { status, ...rest } = values;
        const newValues = { status: boolToStatus(status), ...rest };
        const { courseware } = this.props;
        const { currentItem } = courseware;
        const { resourceList } = currentItem;

        let resourceIdList;
        if (resourceList) {
          resourceIdList = resourceList.map(item => item.id);
        }

        const matchId = this.isEdit();
        if (matchId) {
          const params = {
            id: matchId,
            resourceList: resourceIdList,
            ...newValues,
          };
          this.props.dispatch({
            type: 'courseware/updateCoursewareItem',
            payload: params,
            states: this.props.location.state,
          });
        } else {
          const params = {
            resourceList: resourceIdList,
            ...newValues,
          };
          this.props.dispatch({
            type: 'courseware/createCoursewareItem',
            payload: params,
            states: this.props.location.state,
          });
        }
      }
    });
  };

  render() {
    const { submitting, courseware, form, loading, resource } = this.props;
    const { modalSelectorDestroy, resourceType } = this.state;
    const { getFieldDecorator } = form;
    const { currentItem } = courseware;
    const { code, title, digest, category, status, resourceList = [] } = currentItem;

    const imageColumns = [{
      title: '缩略图',
      dataIndex: 'path',
      key: 1,
      render: (text, record) => {
        const { type } = record;
        if (type === Hotax.RESOURCE_IMAGE) {
          return (
            <div className={styles.picture}>
              <img src={genAbsolutePicUrl(text)} alt="" />
            </div>
          );
        } else if (type === Hotax.RESOURCE_AUDIOBOOK) {
          const { img } = record;
          const { path } = img || {};
          return (
            <div className={styles.picture}>
              <img src={genAbsolutePicUrl(path)} alt="" />
            </div>
          );
        } else {
          return (
            <div className={styles.video}>
              <Icon style={{ fontSize: 50 }} type="video-camera" />
            </div>
          );
        }
      },
      width: '10%',
      align: 'center',
    }, {
      title: '资源编号',
      dataIndex: 'code',
      key: 2,
      width: '25%',
      render: (text, record) => <a className="a-link" onClick={() => this.handleResourceEdit(record)}>{text}</a>,
    }, {
      title: '资源名称',
      dataIndex: 'name',
      key: 3,
      width: '25%',
    }, {
      title: '资源类型',
      dataIndex: 'type',
      key: 4,
      width: '10%',
      render: text => getResourceTypeName(text),
      align: 'center',
    }];

    const renderCardName = () => {
      return (
        <Button
          type="primary"
          onClick={this.handleSelectorModalShow}
        >资源列表
        </Button>
      );
    };
    const renderModalTitle = () => {
      return (
        <Radio.Group
          value={resourceType}
          onChange={this.handleRadioChange}
        >
          <Radio.Button value="Picture">图片</Radio.Button>
          <Radio.Button value="Video">视频</Radio.Button>
          <Radio.Button value="AudioBook">有声读物</Radio.Button>
        </Radio.Group>
      );
    };
    const renderResourceList = () => {
      return (
        <AXDragSortTable
          columns={imageColumns}
          data={resourceList}
          onChange={this.handleDragSortTableChange}
        />
      );
    };
    return (
      <div>
        <Card title="基础信息" style={{ marginBottom: 16 }}>
          <Form>
            <Form.Item hasFeedback label={fieldLabels.code} {...formItemLayout}>
              {getFieldDecorator('code', {
                rules: [
                  {
                    required: true, message: '请填写课件编号',
                  }, {
                    pattern: /^[a-zA-Z0-9|-]+$/g, message: '编号包含非法字符',
                  },
                ],
                initialValue: code,
              })(
                <Input
                  placeholder="请输入"
                />
              )}
            </Form.Item>
            <Form.Item hasFeedback label={fieldLabels.title} {...formItemLayout}>
              {getFieldDecorator('title', {
                rules: [{ required: true, message: '请填写课件名称' }],
                initialValue: title,
              })(
                <Input placeholder="请输入" />
              )}
            </Form.Item>
            <Form.Item hasFeedback label={fieldLabels.category} {...formItemLayout}>
              {getFieldDecorator('category', {
                initialValue: category,
              })(
                <Input placeholder="请输入" />
              )}
            </Form.Item>
            <Form.Item label={fieldLabels.digest} {...formItemLayout}>
              {getFieldDecorator('digest', {
                initialValue: digest,
              })(
                <Input.TextArea rows={4} placeholder="请输入" />
              )}
            </Form.Item>
            <Form.Item label={fieldLabels.status} {...formItemLayout}>
              {getFieldDecorator('status', {
                valuePropName: 'checked',
                initialValue: statusToBool(status),
              })(
                <Switch
                  checkedChildren="正常"
                  unCheckedChildren="删除"
                />
              )}
            </Form.Item>
          </Form>
        </Card>
        <Card title={renderCardName()} style={{ marginBottom: 70 }}>
          {renderResourceList()}
          {!modalSelectorDestroy && (
            <Modal
              visible
              width={1100}
              footer={null}
              title={renderModalTitle()}
              maskClosable={false}
              onCancel={this.handleSelectorCancel}
            >
              <Selector
                multiple={resourceType === 'Picture' || resourceType === 'AudioBook'}
                loading={loading}
                selectorName={resourceType}
                fixedName="Resource"
                list={resource.list}
                pageNo={resource.pageNo}
                pageSize={resource.pageSize}
                totalSize={resource.totalSize}
                selectedRows={resourceList}
                onCancel={this.handleSelectorCancel}
                onChange={this.handleSelectorChange}
                onFinish={this.handleSelectorFinish}
              />
            </Modal>
          )}
        </Card>
        <FooterToolbar style={{ width: '100%' }}>
          <Button
            onClick={this.handlePageBack}
            style={{ marginRight: 10 }}
          >取消
          </Button>
          <Button
            type="primary"
            loading={submitting}
            onClick={this.handlePageSubmit}
          >提交
          </Button>
        </FooterToolbar>
      </div>
    );
  }
}
