import React, { PureComponent } from 'react';
import { Card, Form, Input, Button } from 'antd';
import { connect } from 'dva';
import { routerRedux } from 'dva/router';
import Uploader from '../../../components/AXUpload';
import { Hotax } from '../../../utils/config';
import PageHeaderLayout from '../../../layouts/PageHeaderLayout';

const formItemLayout = {
  labelCol: {
    xs: { span: 24 },
    sm: { span: 6 },
  },
  wrapperCol: {
    xs: { span: 24 },
    sm: { span: 14 },
    md: { span: 12 },
  },
};
const submitFormLayout = {
  wrapperCol: {
    xs: { span: 24, offset: 0 },
    sm: { span: 12, offset: 6 },
  },
};

function getFileObject(params) {
  if (!params) { return; }
  const { format, url, path, name, size } = params;
  return { url, path, name, size, type: `image/${format}` };
}
function picNameFormat(name) {
  if (!name) return name;
  const separatorIndex = name.lastIndexOf('.');
  if (separatorIndex !== -1) {
    return name.substring(0, separatorIndex);
  }
  return name;
}

@Form.create()
@connect(({ loading }) => ({
  submitting: loading.models.resource,
}))
export default class PictureSingleUpload extends PureComponent {
  constructor(props) {
    super(props);
    const { location } = props;
    const { state } = location;
    this.state = {
      fileList: [getFileObject(state)],
      code: state.code || '',
    };
  }
  handleOnChangeEvent = (fileList) => {
    this.setState({ fileList });
    return fileList;
  };
  handlePageBack = () => {
    const { UIParams, Queryers, isCard } = this.props.location.state || {};
    this.props.dispatch(
      routerRedux.push({
        pathname: '/resource/picture',
        state: { UIParams, Queryers, isCard },
      })
    );
  };
  handlePageSubmit = (e) => {
    e.preventDefault();
    this.props.form.validateFieldsAndScroll((err, values) => {
      if (!err) {
        const { id, type, UIParams, Queryers } = this.props.location.state || {};
        const { fileList, ...params } = values;
        if (Array.isArray(fileList) && fileList.length) {
          params.url = fileList[0].url;
        }
        params.id = id;
        params.type = type;
        params.status = Hotax.STATUS_NORMAL;
        this.props.dispatch({
          type: 'resource/updateImage',
          payload: params,
          states: { UIParams, Queryers },
        });
      }
    });
  };
  render() {
    const { form, submitting } = this.props;
    const { getFieldDecorator } = form;
    const { fileList, code } = this.state;
    const firstPicture = fileList[0] || {};
    const { type, size, path, name } = firstPicture;

    return (
      <PageHeaderLayout>
        <Card>
          <Form onSubmit={this.handlePageSubmit}>
            <Form.Item label="图片编号" {...formItemLayout}>
              {getFieldDecorator('code', {
                rules: [{ required: true, message: '图片编号不能为空' }],
                initialValue: code,
              })(
                <Input />
              )}
            </Form.Item>
            <Form.Item label="图片上传" {...formItemLayout}>
              {getFieldDecorator('fileList', {
                getValueFromEvent: this.handleOnChangeEvent,
              })(
                <Uploader
                  forbidden={
                    !((code && /^[a-zA-Z0-9|-]+$/ig.test(code)))
                  }
                  fileCode={code}
                  fileList={fileList}
                  accept="image"
                  multiple={false}
                  totalLimit={1}
                />
              )}
            </Form.Item>
            <Form.Item label="图片名称" {...formItemLayout}>
              {getFieldDecorator('name', {
                rules: [{ required: true, message: '图片名称不能为空' }],
                initialValue: picNameFormat(name),
              })(
                <Input />
              )}
            </Form.Item>
            <Form.Item label="图片路径" {...formItemLayout}>
              {getFieldDecorator('path', {
                initialValue: path,
              })(
                <Input disabled />
              )}
            </Form.Item>
            <Form.Item label="图片格式" {...formItemLayout}>
              {getFieldDecorator('format', {
                initialValue: type ? type.split('/')[1] : '',
              })(
                <Input disabled />
              )}
            </Form.Item>
            <Form.Item label="图片大小" {...formItemLayout}>
              {getFieldDecorator('size', {
                initialValue: size,
              })(
                <Input disabled />
              )}
            </Form.Item>
            <Form.Item {...submitFormLayout} style={{ marginTop: 32 }}>
              <Button onClick={this.handlePageBack}>取消</Button>
              <Button
                type="primary"
                htmlType="submit"
                loading={submitting}
                style={{ marginLeft: 8 }}
              >提交
              </Button>
            </Form.Item>
          </Form>
        </Card>
      </PageHeaderLayout>
    );
  }
}
