import React from 'react';
import moment from 'moment';
import { Button } from 'antd';
import { addRowKey, genAbsolutePicUrl } from '../../../utils/utils';
import { StandardTableList } from '../../../components/AXList';
import styles from './PictureTableList.less';

function PictureTableList({
  UIParams, dataSource, loading, totalSize, pageSize, pageNo,
  onFilterClick, onCreateClick, onBatchClick, onEditClick,
}) {
  const batchActions = [{
    key: 'delete',
    name: '批量删除',
  }, {
    key: 'edit',
    name: '批量编辑',
  }];
  const basicSearch = {
    keys: [{
      name: '图片编号',
      field: 'code',
    }, {
      name: '图片名称',
      field: 'name',
    }],
  };
  const pagination = {
    pageNo,
    pageSize,
    totalSize,
  };
  const renderThumbPic = (url) => {
    return (
      <div className={styles.thumbPic}>
        <img src={url} alt="thumb" />
      </div>
    );
  };
  const renderMetaData = ({ code, name }) => {
    return (
      <div className={styles.meta}>
        <p>{name}</p>
        <p>{code}</p>
      </div>
    );
  };
  const renderActions = (item) => {
    return (
      <div>
        <Button
          size="small"
          type="primary"
          className="editBtn"
          onClick={() => onEditClick(item)}
        >编辑
        </Button>
      </div>
    );
  };
  const columns = [{
    title: '缩略图',
    key: 1,
    dataIndex: 'path',
    render: text => renderThumbPic(genAbsolutePicUrl(text)),
    width: '20%',
  }, {
    title: '名称/编号',
    key: 2,
    dataIndex: 'meta',
    render: (_, record) => renderMetaData(record),
    width: '25%',
  }, {
    title: '格式',
    key: 3,
    dataIndex: 'format',
    width: '13%',
  }, {
    title: '大小(Byte)',
    key: 4,
    dataIndex: 'size',
    width: '12%',
  }, {
    title: '更新日期',
    key: 5,
    dataIndex: 'gmtModified',
    render: text => moment(text).format('YYYY-MM-DD HH:mm:ss'),
    width: '20%',
  }, {
    title: '操作',
    key: 6,
    dataIndex: 'action',
    render: (_, record) => renderActions(record),
    width: '10%',
    align: 'right',
  }];

  return (
    <StandardTableList
      columns={columns}
      loading={loading}
      dataSource={addRowKey(dataSource)}
      keepUIState={{ ...UIParams }}
      header={{ basicSearch, onFilterClick, onCreateClick }}
      footer={{ pagination, batchActions, onBatchClick }}
      showStatusSelect={false}
    />
  );
}

export default PictureTableList;
