/* eslint-disable no-trailing-spaces */
import React, { Component } from 'react';
import moment from 'moment';
import pathToRegexp from 'path-to-regexp';
import { connect } from 'dva';
import { routerRedux } from 'dva/router';
import { Card, Modal, Table, Button } from 'antd';
import FooterToolbar from '../../../components/FooterToolbar';
import { Hotax } from '../../../utils/config';
import { renderOrderSplitStatus, renderOrderStatus, renderProductType, provinceCodeToName } from '../../../utils/utils';
import styles from './OrderDetail.less';

@connect(({ loading, trade }) => ({
  trade,
  loading: loading.models.trade,
}))
export default class OrderDetail extends Component {
  componentDidMount() {
    const match = pathToRegexp('/trade/order/view/:id')
      .exec(this.props.location.pathname);
    if (match) {
      this.props.dispatch({
        type: 'trade/fetchOrderItem',
        payload: { id: match[1] },
      });
    }
  }
  /**
   * 作废订单
   */
  invalidOrders = ({ id, serialNo }) => {
    Modal.confirm({
      okText: '确定',
      cancelText: '取消',
      title: `你确定要作废编号: ${serialNo}订单?`,
      onOk: () => {
        this.props.dispatch({
          type: 'trade/invalidOrderItem',
          payload: { id },
          states: { orderId: id },
        });
      },
    });
  };

  /**
   * 支付订单
   */
  payOrders = ({ id, serialNo, finalPrice }) => {
    Modal.confirm({
      okText: '支付',
      cancelText: '取消',
      title: `你确定要支付编号: ${serialNo}订单?`,
      content: <span style={{ color: '#f00', fontWeight: 'bold' }}>{`金额: ¥${finalPrice}`}</span>,
      onOk: () => {
        this.props.dispatch({
          type: 'trade/payOrderItem',
          payload: { id },
          states: { orderId: id },
        });
      },
    });
  };
  handlePageBack = () => {
    this.props.dispatch(routerRedux.push({
      pathname: '/trade/order/list',
      state: this.props.location.state,
    }));
  };

  render() {
    const { trade } = this.props;
    const { currentItem } = trade;
    const {
      id,
      note,
      goods,
      serialNo,
      name,
      mobile,
      address,
      userCode,
      provinceCode,
      cityName,
      zoneName,
      classroomName,
      merchantName,
      splitStatus,
      gmtCreated,
      gmtModified,
      orderStatus,
      originPrice,
      adjustPrice,
      finalPrice,
    } = currentItem;

    const orderPreviewColumns = [{
      dataIndex: 'col-1',
      key: 1,
      width: '50%',
    }, {
      dataIndex: 'col-2',
      key: 2,
      width: '50%',
    }];
    const orderPreviewData = [{
      key: 'row-1',
      'col-1': `订单编号: ${serialNo}`,
      'col-2': `订单备注: ${note || '无'}`,
    }, {
      key: 'row-2',
      'col-1': `拆分状态: ${renderOrderSplitStatus(splitStatus)}`,
      'col-2': `拆分原因: ${splitStatus === Hotax.ORDER_SPLITED ? '商品属性不同或属于不同商家，订单被拆分为多个子订单分开处理或配送' : ''}`,
    }, {
      key: 'row-3',
      'col-1': `创建时间: ${moment(gmtCreated).format('YYYY-MM-DD HH:mm:ss')}`,
      'col-2': `更新时间: ${moment(gmtModified).format('YYYY-MM-DD HH:mm:ss')}`,
    }];
    const userInfoData = [{
      key: 'row-1',
      'col-1': `购买用户: ${provinceCodeToName(provinceCode)}${cityName}${zoneName}${classroomName}【${userCode}】`,
      'col-2': `所属渠道: ${merchantName}`,
    }, {
      key: 'row-2',
      'col-1': `收货人: ${name}`,
      'col-2': `手机号码: ${mobile}`,
    }, {
      key: 'row-3',
      'col-1': `收货地址: ${address}`,
    }];
    const orderDetailColumns = [{
      title: '产品名称',
      key: 1,
      dataIndex: 'name',
      width: '20%',
    }, {
      title: '产品编号',
      key: 2,
      dataIndex: 'code',
      width: '18%',
    }, {
      title: '产品类型',
      key: 3,
      dataIndex: 'type',
      render: text => renderProductType(text),
      width: '16%',
      align: 'center',
    }, {
      title: '数量',
      key: 4,
      dataIndex: 'quantity',
      width: '15%',
      align: 'center',
    }, {
      title: '付款方式',
      key: 5,
      dataIndex: 'chargeUnit',
      width: '16%',
      align: 'center',
    }, {
      title: '金额',
      key: 6,
      dataIndex: 'merchantPrice',
      render: text => `¥ ${text}`,
      width: '16%',
      align: 'right',
    }];
    return (
      <div>
        {/* 该订单的一些基础信息 */}
        <Card style={{ marginBottom: 70 }}>
          <Table
            bordered
            size="small"
            pagination={false}
            showHeader={false}
            className={styles.orderTable}
            columns={orderPreviewColumns}
            dataSource={orderPreviewData}
            title={() => '订单概要'}
            footer={() => {
              return (
                <div className={styles.previewTableFooter}>
                  <span>
                    订单状态:&nbsp;
                    <a style={{ color: '#f00' }}>
                      {renderOrderStatus(orderStatus, true)}
                    </a>
                  </span>
                  <span>
                    {orderStatus === Hotax.ORDER_UNPAID && (
                      <span>
                        <Button
                          size="small"
                          type="primary"
                          onClick={() => this.payOrders({ id, serialNo, finalPrice })}
                        >立即支付
                        </Button>
                        <Button
                          size="small"
                          style={{ marginLeft: 10 }}
                          onClick={() => this.invalidOrders({ id, serialNo })}
                        >作废订单
                        </Button>
                      </span>
                    )}
                  </span>
                </div>
              );
            }}
          />
          {/* 该订单中包含的商品清单 */}
          <Table
            bordered
            size="small"
            pagination={false}
            className={styles.orderTable}
            columns={orderDetailColumns}
            dataSource={goods}
            rowKey={record => record.id}
            title={() => '订单详情'}
            footer={() => {
              return (
                <div className={styles.detailTableFooter}>
                  <p>订单总价:&nbsp;<span>{`¥${originPrice}`}</span></p>
                  <p>优惠金额:&nbsp;<span>{`¥${adjustPrice}`}</span></p>
                  <p>实付金额:&nbsp;<span>{`¥${finalPrice}`}</span></p>
                </div>
              );
            }}
          />
          {/* 该订单的收货信息等内容 */}
          <Table
            bordered
            size="small"
            pagination={false}
            showHeader={false}
            className={styles.orderTable}
            columns={orderPreviewColumns}
            dataSource={userInfoData}
            title={() => '收货信息'}
          />
        </Card>
        {/* 底部工具条 */}
        <FooterToolbar style={{ width: '100%' }}>
          <Button type="primary" onClick={this.handlePageBack}>返回订单列表</Button>
        </FooterToolbar>
      </div>
    );
  }
}
