/* eslint-disable no-trailing-spaces */
import React, { Component } from 'react';
import moment from 'moment';
import { connect } from 'dva';
import { routerRedux } from 'dva/router';
import { Card, Table, Modal, Form, Popover, Divider, Input } from 'antd';
import { StandardTableList } from '../../../components/AXList';
import { addRowKey, renderOrderStatus, renderGoodsType, provinceCodeToName } from '../../../utils/utils';
import { Hotax } from '../../../utils/config';
import styles from './OrderList.less';

@connect(({ loading, trade }) => ({
  trade,
  loading: loading.models.trade,
}))
@Form.create()
export default class OrderListPage extends Component {
  constructor(props) {
    super(props);
    const { state } = props.location;
    this.state = {
      currentTab: 'all',
      logisticsModalDestroy: true,
      UIParams: (state || {}).UIParams, // 组件的状态参数
      Queryers: (state || {}).Queryers, // 查询的条件参数
    };
  }
  componentDidMount() {
    const { currentTab } = this.state;
    this.props.dispatch({
      type: 'trade/fetchOrderList',
      payload: {
        orderStatus: currentTab,
        ...this.state.Queryers,
      },
    });
  }
  handleCardTabChange = (key) => {
    this.setState({
      currentTab: key,
    });
    this.props.dispatch({
      type: 'trade/fetchOrderList',
      payload: { orderStatus: key },
    });
  };
  handleCreateOperation = () => {
    this.props.dispatch(routerRedux.push({
      pathname: '/trade/order/create',
      state: this.state,
    }));
  };
  handleViewOperation = (id) => {
    this.props.dispatch(routerRedux.push({
      pathname: `/trade/order/view/${id}`,
      state: this.state,
    }));
  };
  handleViewSubOrderOperation = (id) => {
    this.props.dispatch(routerRedux.push({
      pathname: `/trade/order/sub/${id}`,
      state: this.state,
    }));
  };
  handleFilterOperation = (params, states) => {
    const { currentTab } = this.state;
    this.props.dispatch({
      type: 'trade/fetchOrderList',
      payload: { orderStatus: currentTab, ...params },
    });
    this.setState({
      UIParams: states,
      Queryers: params,
    });
  };
  handleLogisticsModalShow = () => {
    this.setState({ logisticsModalDestroy: false });
  };
  handleLogisticsModalHide = () => {
    this.setState({ logisticsModalDestroy: true });
  };
  /**
   * 立即发货
   */
  orderDelivery = ({ id }) => {
    this.props.form.validateFields((errors, values) => {
      if (!errors) {
        this.props.dispatch({
          type: 'trade/sendOrderItem',
          payload: { id, ...values },
          states: { orderId: id },
        });
        this.handleLogisticsModalHide();
      }
    });
  };
  /**
   * 确认收货
   */
  orderReceipt = ({ id, serialNo }) => {
    Modal.confirm({
      okText: '确定',
      cancelText: '取消',
      title: '你确定用户已收到该订单内的货物?',
      content: `订单号: ${serialNo}`,
      onOk: () => {
        this.props.dispatch({
          type: 'trade/receiveOrderItem',
          payload: { id },
          states: { orderId: id },
        });
      },
    });
  };
  /**
   * 作废订单
   */
  invalidOrders = ({ id, serialNo }) => {
    Modal.confirm({
      okText: '确定',
      cancelText: '取消',
      title: `你确定要作废编号: ${serialNo}订单?`,
      onOk: () => {
        this.props.dispatch({
          type: 'trade/invalidOrderItem',
          payload: { id },
          states: this.state,
        });
      },
    });
  };

  /**
   * 支付订单
   */
  payOrders = ({ id, serialNo, finalPrice }) => {
    Modal.confirm({
      okText: '支付',
      cancelText: '取消',
      title: `你确定要支付编号: ${serialNo}订单?`,
      content: <span style={{ color: '#f00', fontWeight: 'bold' }}>{`金额: ¥${finalPrice}`}</span>,
      onOk: () => {
        this.props.dispatch({
          type: 'trade/payOrderItem',
          payload: { id },
          states: this.state,
        });
      },
    });
  };

  render() {
    const { logisticsModalDestroy } = this.state;
    const { loading, trade, form } = this.props;
    const { getFieldDecorator } = form;
    const { list, totalSize, pageSize, pageNo } = trade;

    const renderOperation = ({ orderStatus, id, serialNo, finalPrice }) => {
      return (
        <div className={styles.operation}>
          <a onClick={() => this.handleViewOperation(id)}>详情</a>
          {orderStatus === Hotax.ORDER_UNPAID && (
            <span>
              <Divider type="vertical" />
              <a onClick={() => this.payOrders({ id, serialNo, finalPrice })}>支付</a>
            </span>
          )}
          {orderStatus === Hotax.ORDER_UNPAID && (
            <span>
              <Divider type="vertical" />
              <a onClick={() => this.invalidOrders({ id, serialNo })}>作废</a>
            </span>
          )}
        </div>
      );
    };
    const basicSearch = {
      keys: [{
        name: '订单编号',
        field: 'code',
      }, {
        name: '终端编号',
        field: 'userCode',
      }],
    };
    const pagination = {
      pageNo,
      pageSize,
      totalSize,
    };
    const columns = [{
      title: '订单编号',
      key: 1,
      dataIndex: 'serialNo',
      width: '13%',
    }, {
      title: '用户信息',
      key: 2,
      width: '25%',
      render: (_, record) => {
        const { userCode, provinceCode, cityName, zoneName, merchantName } = record;
        return (
          <div className={styles.user}>
            <p>
              <span>终端编号:&nbsp;</span>
              {userCode}
            </p>
            <p>
              <span>所属校区:&nbsp;</span>
              {`${provinceCodeToName(provinceCode)}${cityName}${zoneName}`}
            </p>
            <p>
              <span>所属渠道:&nbsp;</span>
              {merchantName}
            </p>
          </div>
        );
      },
    }, {
      title: '价格信息',
      key: 3,
      width: '15%',
      render: (_, record) => {
        const { originPrice, adjustPrice, finalPrice } = record;
        return (
          <div className={styles.price}>
            <p>
              <span>原价:&nbsp;</span>
              <a>{`¥${originPrice}`}</a>
            </p>
            <p>
              <span>优惠:&nbsp;</span>
              <a>{`¥${adjustPrice}`}</a>
            </p>
            <p>
              <span>实付:&nbsp;</span>
              <a>{`¥${finalPrice}`}</a>
            </p>
          </div>
        );
      },
    }, {
      title: '收货信息',
      key: 4,
      width: '8%',
      render: (_, record) => {
        const { name, mobile, address } = record;
        return (
          <Popover
            placement="top"
            content={
              <div>
                <p>
                  <span>收货人:&nbsp;</span>
                  {name}
                </p>
                <p>
                  <span>手机号码:&nbsp;</span>
                  {mobile}
                </p>
                <p>
                  <span>收货地址:&nbsp;</span>
                  {address}
                </p>
              </div>
            }
          >
            {name}
          </Popover>
        );
      },
    }, {
      title: '订单状态',
      key: 5,
      dataIndex: 'orderStatus',
      render: text => renderOrderStatus(text),
      width: '8%',
    }, {
      title: '下单时间',
      key: 6,
      dataIndex: 'gmtCreated',
      render: text => moment(text).format('YYYY-MM-DD HH:mm:ss'),
      width: '16%',
    }, {
      title: '操作',
      key: 7,
      dataIndex: 'operation',
      render: (_, record) => renderOperation(record),
      width: '15%',
      align: 'right',
    }];

    const expandedRowRender = ({ detailList }) => {
      const renderSubOrderOperation = ({ orderStatus, id, serialNo }) => {
        return (
          <div className={styles.operation}>
            <a onClick={() => this.handleViewSubOrderOperation(id)}>详情</a>
            {orderStatus === Hotax.ORDER_FORSEND && (
              <span>
                <Divider type="vertical" />
                <a onClick={this.handleLogisticsModalShow}>发货</a>
              </span>
            )}
            {orderStatus === Hotax.ORDER_SENT && (
              <span>
                <Divider type="vertical" />
                <a onClick={() => this.orderReceipt({ id, serialNo })}>收货</a>
              </span>
            )}
            {!logisticsModalDestroy && (
              <Modal
                visible
                maskClosable={false}
                title={`订单号: ${serialNo}`}
                okText="发货"
                cancelText="取消"
                onCancel={this.handleLogisticsModalHide}
                onOk={() => this.orderDelivery({ id })}
              >
                <Form>
                  <Form.Item
                    hasFeedback
                    label="物流单号"
                    labelCol={{ xs: { span: 24 }, md: { span: 7 } }}
                    wrapperCol={{ xs: { span: 24 }, md: { span: 14 } }}
                  >
                    {getFieldDecorator('trackNo', {
                      rules: [{ required: true, message: '请填写物流单号!' }],
                    })(
                      <Input placeholder="请填写物流单号" />
                    )}
                  </Form.Item>
                </Form>
              </Modal>
            )}
          </div>
        );
      };
      const subOrderColumns = [{
        title: '子订单编号',
        key: 1,
        dataIndex: 'serialNo',
        width: '20%',
        align: 'center',
      }, {
        title: '商品类型',
        key: 2,
        dataIndex: 'type',
        render: text => renderGoodsType(text),
        width: '20%',
        align: 'center',
      }, {
        title: '子订单价格',
        key: 3,
        dataIndex: 'originPrice',
        render: text => `¥${text}`,
        width: '20%',
        align: 'center',
      }, {
        title: '子订单状态',
        key: 4,
        dataIndex: 'orderStatus',
        render: text => renderOrderStatus(text),
        width: '20%',
        align: 'center',
      }, {
        title: '操作',
        key: 5,
        width: '20%',
        render: (_, record) => renderSubOrderOperation(record),
      }];
      return (
        <Table
          bordered
          size="small"
          pagination={false}
          rowKey={record => record.id}
          columns={subOrderColumns}
          dataSource={detailList}
        />
      );
    };

    const cardTabList = [{
      key: 'all',
      tab: '全部状态',
    }, {
      key: Hotax.ORDER_UNPAID,
      tab: '未支付',
    }, {
      key: Hotax.ORDER_PAYOK,
      tab: '已支付',
    }, {
      key: Hotax.ORDER_CANCEL,
      tab: '已作废',
    }, {
      key: Hotax.ORDER_FORSEND,
      tab: '待发货',
    }, {
      key: Hotax.ORDER_COMPLETE,
      tab: '已完成',
    }];

    return (
      <Card
        tabList={cardTabList}
        onTabChange={this.handleCardTabChange}
      >
        <StandardTableList
          columns={columns}
          loading={loading}
          rowSelectable={false}
          showStatusSelect={false}
          dataSource={addRowKey(list)}
          expandedRowRender={expandedRowRender}
          header={{
            basicSearch,
            onFilterClick: this.handleFilterOperation,
            onCreateClick: this.handleCreateOperation,
          }}
          footer={{
            pagination,
          }}
          keepUIState={{ ...this.state.UIParams }}
        />
      </Card>
    );
  }
}
