/* eslint-disable no-trailing-spaces */
import React, { Component } from 'react';
import moment from 'moment';
import pathToRegexp from 'path-to-regexp';
import { connect } from 'dva';
import { routerRedux } from 'dva/router';
import { Card, Modal, Form, Input, Table, Button } from 'antd';
import FooterToolbar from '../../../components/FooterToolbar';
import { Hotax } from '../../../utils/config';
import { renderOrderStatus, renderProductType, provinceCodeToName } from '../../../utils/utils';
import styles from './OrderDetail.less';

@connect(({ loading, trade }) => ({
  trade,
  loading: loading.models.trade,
}))
@Form.create()
export default class SubOrderDetailPage extends Component {
  state = {
    logisticsModalDestroy: true,
  };
  componentDidMount() {
    const match = pathToRegexp('/trade/order/sub/:id')
      .exec(this.props.location.pathname);
    if (match) {
      this.props.dispatch({
        type: 'trade/fetchSubOrderItem',
        payload: { id: match[1] },
      });
    }
  }
  handleLogisticsModalShow = () => {
    this.setState({ logisticsModalDestroy: false });
  };
  handleLogisticsModalHide = () => {
    this.setState({ logisticsModalDestroy: true });
  };
  /**
   * 立即发货
   */
  orderDelivery = ({ id }) => {
    this.props.form.validateFields((errors, values) => {
      if (!errors) {
        this.props.dispatch({
          type: 'trade/sendOrderItem',
          payload: { id, ...values },
          states: { orderId: id },
        });
        this.handleLogisticsModalHide();
      }
    });
  };
  /**
   * 确认收货
   */
  orderReceipt = ({ id, serialNo }) => {
    Modal.confirm({
      okText: '确定',
      cancelText: '取消',
      title: '你确定用户已收到该订单内的货物?',
      content: `订单号: ${serialNo}`,
      onOk: () => {
        this.props.dispatch({
          type: 'trade/receiveOrderItem',
          payload: { id },
          states: { orderId: id },
        });
      },
    });
  };
  handlePageBack = () => {
    this.props.dispatch(routerRedux.push({
      pathname: '/trade/order/list',
      state: this.props.location.state,
    }));
  };

  render() {
    const { logisticsModalDestroy } = this.state;
    const { trade, form } = this.props;
    const { currentItem } = trade;
    const { getFieldDecorator } = form;
    const {
      id,
      note,
      goods,
      serialNo,
      name,
      mobile,
      address,
      userCode,
      provinceCode,
      cityName,
      zoneName,
      classroomName,
      merchantName,
      gmtCreated,
      gmtModified,
      orderStatus,
    } = currentItem;

    const orderPreviewColumns = [{
      dataIndex: 'col-1',
      key: 1,
      width: '50%',
    }, {
      dataIndex: 'col-2',
      key: 2,
      width: '50%',
    }];
    const orderPreviewData = [{
      key: 'row-1',
      'col-1': `订单编号: ${serialNo}`,
      'col-2': `订单备注: ${note || '无'}`,
    }, {
      key: 'row-2',
      'col-1': `创建时间: ${moment(gmtCreated).format('YYYY-MM-DD HH:mm:ss')}`,
      'col-2': `更新时间: ${moment(gmtModified).format('YYYY-MM-DD HH:mm:ss')}`,
    }];
    const userInfoData = [{
      key: 'row-1',
      'col-1': `购买用户: ${provinceCodeToName(provinceCode)}${cityName}${zoneName}${classroomName}【${userCode}】`,
      'col-2': `所属渠道: ${merchantName}`,
    }, {
      key: 'row-2',
      'col-1': `收货人: ${name}`,
      'col-2': `手机号码: ${mobile}`,
    }, {
      key: 'row-3',
      'col-1': `收货地址: ${address}`,
    }];
    const orderDetailColumns = [{
      title: '产品名称',
      key: 1,
      dataIndex: 'name',
      width: '20%',
    }, {
      title: '产品编号',
      key: 2,
      dataIndex: 'code',
      width: '18%',
    }, {
      title: '产品类型',
      key: 3,
      dataIndex: 'type',
      render: text => renderProductType(text),
      width: '16%',
      align: 'center',
    }, {
      title: '数量',
      key: 4,
      dataIndex: 'quantity',
      width: '15%',
      align: 'center',
    }, {
      title: '付款方式',
      key: 5,
      dataIndex: 'chargeUnit',
      width: '16%',
      align: 'center',
    }, {
      title: '单价',
      key: 6,
      dataIndex: 'merchantPrice',
      render: text => `¥ ${text}`,
      width: '16%',
      align: 'center',
    }];
    return (
      <div>
        {/* 该订单的一些基础信息 */}
        <Card style={{ marginBottom: 70 }}>
          <Table
            bordered
            size="small"
            pagination={false}
            showHeader={false}
            className={styles.orderTable}
            columns={orderPreviewColumns}
            dataSource={orderPreviewData}
            title={() => '子订单概要'}
            footer={() => {
              return (
                <div className={styles.previewTableFooter}>
                  <span>
                    订单状态:&nbsp;
                    <a style={{ color: '#f00' }}>
                      {renderOrderStatus(orderStatus, true)}
                    </a>
                  </span>
                  <span>
                    {orderStatus === Hotax.ORDER_FORSEND && (
                      <span>
                        <Button
                          size="small"
                          type="primary"
                          onClick={this.handleLogisticsModalShow}
                        >立即发货
                        </Button>
                      </span>
                    )}
                  </span>
                  <span>
                    {orderStatus === Hotax.ORDER_SENT && (
                      <span>
                        <Button
                          size="small"
                          type="primary"
                          onClick={() => this.orderReceipt({ id, serialNo })}
                        >确认收货
                        </Button>
                      </span>
                    )}
                  </span>
                </div>
              );
            }}
          />
          {/* 该订单中包含的商品清单 */}
          <Table
            bordered
            size="small"
            pagination={false}
            className={styles.orderTable}
            columns={orderDetailColumns}
            dataSource={goods}
            rowKey={record => record.id}
            title={() => '子订单详情'}
          />
          {/* 该订单的收货信息等内容 */}
          <Table
            bordered
            size="small"
            pagination={false}
            showHeader={false}
            className={styles.orderTable}
            columns={orderPreviewColumns}
            dataSource={userInfoData}
            title={() => '收货信息'}
          />
          {/* 确认发货弹框-填写物流单号 */}
          {
            !logisticsModalDestroy && (
              <Modal
                visible
                maskClosable={false}
                title={`订单号: ${serialNo}`}
                okText="发货"
                cancelText="取消"
                onCancel={this.handleLogisticsModalHide}
                onOk={() => this.orderDelivery({ id })}
              >
                <Form>
                  <Form.Item
                    hasFeedback
                    label="物流单号"
                    labelCol={{ xs: { span: 24 }, md: { span: 7 } }}
                    wrapperCol={{ xs: { span: 24 }, md: { span: 14 } }}
                  >
                    {getFieldDecorator('trackNo', {
                      rules: [{ required: true, message: '请填写物流单号!' }],
                    })(
                      <Input placeholder="请填写物流单号" />
                    )}
                  </Form.Item>
                </Form>
              </Modal>
            )
          }
        </Card>
        {/* 底部工具条 */}
        <FooterToolbar style={{ width: '100%' }}>
          <Button type="primary" onClick={this.handlePageBack}>返回订单列表</Button>
        </FooterToolbar>
      </div>
    );
  }
}
